.. _examples:

Examples
============

Here is a list of example notebooks to illustrate how to use pdbufr.

Generic reader
++++++++++++++

.. toctree::
    :maxdepth: 1

    r_generic_aircraft.ipynb
    r_generic_radiosonde.ipynb
    r_generic_synop.ipynb
    r_generic_tropical_cyclone.ipynb
    r_generic_sat.ipynb
    r_generic_ens.ipynb


Flat reader
++++++++++++++

.. toctree::
    :maxdepth: 1

    r_flat.ipynb


Synop reader
++++++++++++++

.. toctree::
    :maxdepth: 1

    r_synop_overview.ipynb


Temp reader
++++++++++++++

.. toctree::
    :maxdepth: 1

    r_temp_overview.ipynb
    r_temp_geopotential.ipynb
